
## simulation.py

This module defines the class responsible for implementing the simulation algorithm for the PPE matching problem.

## strategies.py

This module defines two PPE matching strategies: teh first-come-first-matched strategy and the proximity-match strategy tested by Bala et al. (2021)